@@ -9,6 +9,7 @@ from typing import Optional, Tuple, Any
 
 from dbt.adapters.base import Credentials
 from dbt.adapters.sql import SQLConnectionManager
+from dbt.contracts.connection import AdapterResponse
 from dbt.contracts.connection import Connection
 from dbt.exceptions import (
     DatabaseException,
@@ -24,7 +25,7 @@ class SQLiteCredentials(Credentials):
 
     schemas_and_paths: str
     schema_directory: str
-    extensions: Optional[str]
+    extensions: Optional[str] = None
 
     @property
     def type(self):
@@ -114,6 +115,19 @@ class SQLiteConnectionManager(SQLConnectionManager):
     def get_status(cls, cursor: sqlite3.Cursor):
         return f"OK"#  {cursor.rowcount}"
 
+
+    def get_response(cls, cursor) -> AdapterResponse:
+        """
+        new to support dbt 0.19: this method replaces get_response
+        """
+        message = 'OK'
+        rows = cursor.rowcount
+        return AdapterResponse(
+            _message=message,
+            rows_affected=rows
+        )
+
+
     def cancel(self, connection):
         """ cancel ongoing queries """
 
